@@ -1,9 +1,9 @@
-# $Id: FileSuffix.pm,v 1.3 2002/07/30 10:33:42 jwalt Exp $
+# $Id: FileSuffix.pm,v 1.7 2001/04/30 21:13:48 matt Exp $
 
 package Apache::AxKit::StyleChooser::FileSuffix;
 
 use strict;
-use Apache::Constants qw(OK);
+use Apache::Constants;
 use Apache::URI;
 
 sub handler {
@@ -17,7 +17,7 @@ sub handler {
 #		warn "setting notes: $style\n";
 		$r->notes('preferred_style', $style);
 	}
-	return OK;
+	return DECLINED;
 }
 
 1;
@@ -30,7 +30,8 @@ Apache::AxKit::StyleChooser::FileSuffix - Choose stylesheet using file suffix
 =head1 SYNOPSIS
 
 	PerlTypeHandler Apache::AxKit::StyleChooser::FileSuffix
-	SetHandler AxKit
+	SetHandler perl-script
+	PerlHandler AxKit
 
 =head1 DESCRIPTION
 
@@ -38,7 +39,8 @@ This module lets you pick a stylesheet based on the filename suffix. To use
 it, simply add this module to the list of PerlTypeHandlers:
 
 	PerlTypeHandler Apache::AxKit::StyleChooser::FileSuffix
-	SetHandler AxKit
+	SetHandler perl-script
+	PerlHandler AxKit
 
 Then simply by referencing your xml files as follows:
 
