@@ -1,4 +1,4 @@
-# $Id: UserAgent.pm,v 1.4 2002/07/31 19:50:26 matts Exp $
+# $Id: UserAgent.pm,v 1.3 2001/04/30 21:13:48 matt Exp $
 
 package Apache::AxKit::StyleChooser::UserAgent;
 
@@ -7,7 +7,7 @@ use vars qw($VERSION);
 
 $VERSION = '0.01';
 
-use Apache::Constants qw(OK);
+use Apache::Constants;
 
 sub handler {
     my $r = shift;
@@ -17,17 +17,17 @@ sub handler {
         push (@UAMap, [ split /\s*=>\s*/, $_ ]);
     }
 
-#    warn "checking UA: ", $r->header_in('User-Agent'), "\n";
+#    warn "checking UA: $ENV{HTTP_USER_AGENT}\n";
 
     UA: foreach my $ua (@UAMap) {
-        if ($r->header_in('User-Agent') =~ /$ua->[1]/g) {
+        if ($ENV{HTTP_USER_AGENT} =~ /$ua->[1]/g) {
 #            warn "found UA $ua->[1], setting 'preferred_style' to $ua->[0]\n";
             $r->notes('preferred_style', $ua->[0]);
             last UA;
         }
     }
 
-    return OK;
+    return DECLINED;
 }
 
 1;
@@ -41,7 +41,8 @@ Apache::AxKit::StyleChooser::UserAgent - Choose stylesheets based on the user ag
 
     In your .conf or .htaccess file(s):
     
-    AxAddPlugin Apache::AxKit::StyleChooser::UserAgent
+    PerlHandler Apache::AxKit::StyleChooser::UserAgent \
+                AxKit
 
     PerlSetVar AxUAStyleMap "lynx     => Lynx,\
                              explorer => MSIE,\
@@ -52,13 +53,9 @@ Apache::AxKit::StyleChooser::UserAgent - Choose stylesheets based on the user ag
 
 This module sets the internal preferred style based on the user agent
 string presented by the connecting client.
-To use it, simply add this module as an AxKit plugin that 
-will be run before main AxKit processing is done.
 
-  AxAddPlugin Apache::AxKit::StyleChooser::UserAgent
-
-See the B<AxStyleName> AxKit configuration directive
-for more information on how to setup named styles.
+Remember, use the B<title> attribute in your stylesheet PI to define a
+matching style.
 
 =head1 AUTHOR
 
